@@ -4,7 +4,7 @@ import six
 import sqlalchemy as sa
 
 
-__version__ = '0.3.0'
+__version__ = '0.3.2'
 
 
 class Column(sa.Column):
@@ -41,10 +41,6 @@ class Column(sa.Column):
     def validators(self):
         return self.info['validators'] if 'validators' in self.info else []
 
-    @property
-    def label(self):
-        return self.info['label'] if 'label' in self.info else ''
-
     @property
     def description(self):
         return self.info['description'] if 'description' in self.info else ''
